query{
  phase(id: $phase_id$) {
    cards(after: $after$) {
      edges {
        node {
          id
          fields {
            field {
              id
              label
            }
            value
          }
        }
      }
      pageInfo {
        hasNextPage
        endCursor
      }
    }
  }
}